@@ -6,7 +6,7 @@ import irisml.core
 
 class Task(irisml.core.TaskBase):
     """Save the model's state_dict to the specified file."""
-    VERSION = '0.1.0'
+    VERSION = '0.1.1'
     CACHE_ENABLED = False
 
     @dataclasses.dataclass
@@ -19,5 +19,6 @@ class Task(irisml.core.TaskBase):
 
     def execute(self, inputs):
         state_dict = inputs.model.state_dict()
-        torch.save(state_dict, self._config.path)
+        self.config.path.parent.mkdir(exist_ok=True, parents=True)
+        torch.save(state_dict, self.config.path)
         return self.Outputs()
