@@ -3,7 +3,6 @@ import tempfile
 import unittest
 
 import torch
-from irisml.core import Context
 from irisml.tasks.save_state_dict import Task
 
 
@@ -15,11 +14,20 @@ class TestLoadStateDict(unittest.TestCase):
         with tempfile.TemporaryDirectory() as temp_dir:
             temp_file = pathlib.Path(temp_dir) / 'test.pth'
 
-            config = Task.Config(path=temp_file)
-            task = Task(config, Context())
-            task.execute(inputs)
+            Task(Task.Config(path=temp_file)).execute(inputs)
             self.assertTrue(self._is_equal_state_dict(fake_model.state_dict(), torch.load(temp_file)))
 
+    def test_no_parent_directory(self):
+        fake_model = torch.nn.Conv2d(3, 3, 3)
+
+        inputs = Task.Inputs(model=fake_model)
+        with tempfile.TemporaryDirectory() as temp_dir:
+            temp_file = pathlib.Path(temp_dir) / 'new_directory' / 'another_new_directory' / 'test.pth'
+
+            self.assertFalse(temp_file.exists())
+            Task(Task.Config(path=temp_file)).execute(inputs)
+            self.assertTrue(temp_file.exists())
+
     def _is_equal_state_dict(self, state_dict1, state_dict2):
         if set(state_dict1) != set(state_dict2):
             return False
